/* This is free software. See COPYING for details. */

/* My "new and improved" hello-world LED blinky program for Spark Core --
   please see README. */

#include <application.h>

#define DELAY 250 /* F = 500/DELAY (in Hz), 50% duty cycle */
#define LED D7 // connected to tiny blue on-board LED near USB jack

unsigned long next = 0; // next time (per millis() return) to change LED state
int state = 0;          // current LED state (0=off, non-0=on)

void setup() {
   pinMode(LED, OUTPUT);
}

/* The "official" hello-world blinky program sleeps for huge amounts of
   time (2s+) in loop(), which you should really not do on Spark Core, since
   it's single-threaded -- the fancy networking stuff doesn't happen while
   loop() is executing!

   So, we take a different approach: We use the millis() system clock to
   decide if it's time for us to do something. If not, we return immediately.
   If so, we do it then return. At no time do we delay() inside the loop()
   function.

   Same end result, but a lot less disruptive to the "cloud" features (and
   a much better starting point if you're trying to do something
   complicated where this matters).*/
void loop() {
   unsigned long now = millis();

   if(now < next) return;

   /* After ~49 days, millis() will overflow and wrap around to zero. The
      global "next" overflows and wraps the same way. In the case where
      next is very small (because it just wrapped) and now is big (because
      it hasn't, yet), we need to keep waiting: */
   if(now - next > 3600000) return;

   state = !state;
   digitalWrite(LED, state ? HIGH : LOW);
   next = now + DELAY;
}
